Added display initialization method

The primary display device was being configured to "blank" by
default, which prevented the boot animation from appearing
(unless you got lucky with the hardware composer state).

Bug 6975688

(This reverts an earlier revert.)
diff --git a/services/surfaceflinger/SurfaceFlinger.h b/services/surfaceflinger/SurfaceFlinger.h
index 1f79906..b1fe738 100644
--- a/services/surfaceflinger/SurfaceFlinger.h
+++ b/services/surfaceflinger/SurfaceFlinger.h
@@ -231,9 +231,11 @@
     void signalLayerUpdate();
     void signalRefresh();
 
-    // called on the main thread in response to screenReleased()
+    // called on the main thread in response to initializeDisplays()
+    void onInitializeDisplays();
+    // called on the main thread in response to blank()
     void onScreenReleased();
-    // called on the main thread in response to screenAcquired()
+    // called on the main thread in response to unblank()
     void onScreenAcquired();
 
     void handleMessageTransaction();
@@ -321,6 +323,9 @@
     /* ------------------------------------------------------------------------
      * Display and layer stack management
      */
+    // called when starting, or restarting after system_server death
+    void initializeDisplays();
+
     sp<const DisplayDevice> getDisplayDevice(DisplayID dpy) const {
         return mDisplays.valueFor(dpy);
     }